@@ -6,7 +6,7 @@ setuptools entry points.
 """
 
 # import udiskie.depend first - for side effects!
-from .depend import has_Notify, has_Gtk, _in_X, has_AppIndicator3
+from .depend import has_Notify, has_Gtk, _in_X, _in_Wayland, has_AppIndicator3
 
 import inspect
 import logging.config
@@ -312,7 +312,7 @@ class Daemon(_EntryPoint):
         'notify': True,
         'tray': False,
         'menu': 'flat',
-        'appindicator': False,
+        'appindicator': None,
         'file_manager': 'xdg-open',
         'terminal': '',
         'password_prompt': 'builtin:gui',
@@ -376,12 +376,14 @@ class Daemon(_EntryPoint):
             options['notify'] = False
 
         show_tray = options['tray'] or options['appindicator']
+        if show_tray and _in_Wayland and options['appindicator'] is None:
+            options['appindicator'] = True
 
-        if show_tray and not _in_X:
-            no_X_session = _(
-                "Not run within X session. "
+        if show_tray and not (_in_X or _in_Wayland):
+            no_tray_support = _(
+                "Not run within X or Wayland session."
                 "\nStarting udiskie without tray icon.\n")
-            logging.getLogger(__name__).error(no_X_session)
+            logging.getLogger(__name__).error(no_tray_support)
             show_tray = False
 
         if show_tray and not has_Gtk(3):
